@@ -56,11 +56,19 @@ class CommonSetup(skytools.DBScript):
         self.pgq_queue_name = self.cf.get("pgq_queue_name")
         self.consumer_id = self.cf.get("pgq_consumer_id", self.job_name)
         self.fake = self.cf.getint('fake', 0)
+        self.lock_timeout = self.cf.getfloat('lock_timeout', 10)
 
         if len(self.args) < 3:
             self.log.error("need subcommand")
             sys.exit(1)
 
+    def set_lock_timeout(self, curs):
+        ms = int(1000 * self.lock_timeout)
+        if ms > 0:
+            q = "SET LOCAL statement_timeout = %d" % ms
+            self.log.debug(q)
+            curs.execute(q)
+
     def run(self):
         self.admin()
 
@@ -186,7 +194,7 @@ class ProviderSetup(CommonSetup):
         if not seq_list and self.options.all:
             seq_list = self.provider_get_all_seqs()
 
-        for seq in self.args[3:]:
+        for seq in seq_list:
             self.provider_add_seq(seq)
         self.provider_notify_change()
 
@@ -290,6 +298,8 @@ class ProviderSetup(CommonSetup):
         src_db = self.get_database('provider_db')
         src_curs = src_db.cursor()
 
+        self.set_lock_timeout(src_curs)
+
         src_curs.execute(sql, args)
 
         if self.fake:
